======
xHydro
======

|pypi| |build| |docs| |license|

Hydrological analysis library built with xarray

* Free software: Apache-2.0
* Documentation: https://xhydro.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `Ouranosinc/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`Ouranosinc/cookiecutter-pypackage`: https://github.com/Ouranosinc/cookiecutter-pypackage


.. |pypi| image:: https://img.shields.io/pypi/v/xhydro.svg
        :target: https://pypi.python.org/pypi/xhydro
        :alt: PyPI

.. |build| image:: https://github.com/hydrologie/xhydro/actions/workflows/main.yml/badge.svg
        :target: https://github.com/hydrologie/xhydro/actions
        :alt: Build Status

..
    .. |docs| image:: https://img.shields.io/badge/Docs-GitHub.io-blue
            :target: https://hydrologie.github.io/xhydro/
            :alt: Documentation

.. |docs| image:: https://readthedocs.org/projects/xhydro/badge/?version=latest
        :target: https://xhydro.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. |license| image:: https://img.shields.io/pypi/l/xhydro
        :target: https://github.com/hydrologie/xhydro/blob/main/LICENSE
        :alt: License
